@@ -26,8 +26,17 @@
  *
  */
 
+#ifndef TOTEM_PREFERENCES_H
+#define TOTEM_PREFERENCES_H
+
+G_BEGIN_DECLS
+
 void totem_setup_preferences (Totem *totem);
 void totem_preferences_tvout_setup (Totem *totem);
 void totem_preferences_visuals_setup (Totem *totem);
 
 GtkWidget * bacon_cd_selection_create (void);
+
+G_END_DECLS
+
+#endif /* TOTEM_PREFERENCES_H */
